@@ -55,19 +55,19 @@ def test_current_layout_icon_mode(manager_nospawn, minimal_conf_noscreen):
     config = get_widget_config(CurrentLayout(mode="icon"), minimal_conf_noscreen)
     manager_nospawn.start(config)
     widget = manager_nospawn.c.widget["currentlayout"]
-    img_length = int(widget.eval("self.img_length")[1])
-    padding = int(widget.eval("self.padding")[1])
-    text_length = int(widget.eval("super(type(self), self).calculate_length()")[1])
+    img_length = int(widget.eval("self.img_length"))
+    padding = int(widget.eval("self.padding"))
+    text_length = int(widget.eval("super(type(self), self).calculate_length()"))
 
-    length = int(widget.eval("self.length")[1])
+    length = int(widget.eval("self.length"))
     assert length == img_length + padding * 2
 
     widget.bar.fake_button_press(0, 0, button=3)
-    length = int(widget.eval("self.length")[1])
+    length = int(widget.eval("self.length"))
     assert length == text_length
 
     widget.bar.fake_button_press(0, 0, button=3)
-    length = int(widget.eval("self.length")[1])
+    length = int(widget.eval("self.length"))
     assert length == img_length + padding * 2
 
 
@@ -75,19 +75,19 @@ def test_current_layout_text_mode(manager_nospawn, minimal_conf_noscreen):
     config = get_widget_config(CurrentLayout(mode="text"), minimal_conf_noscreen)
     manager_nospawn.start(config)
     widget = manager_nospawn.c.widget["currentlayout"]
-    img_length = int(widget.eval("self.img_length")[1])
-    padding = int(widget.eval("self.padding")[1])
-    text_length = int(widget.eval("super(type(self), self).calculate_length()")[1])
+    img_length = int(widget.eval("self.img_length"))
+    padding = int(widget.eval("self.padding"))
+    text_length = int(widget.eval("super(type(self), self).calculate_length()"))
 
-    length = int(widget.eval("self.length")[1])
+    length = int(widget.eval("self.length"))
     assert length == text_length
 
     widget.bar.fake_button_press(0, 0, button=3)
-    length = int(widget.eval("self.length")[1])
+    length = int(widget.eval("self.length"))
     assert length == img_length + padding * 2
 
     widget.bar.fake_button_press(0, 0, button=3)
-    length = int(widget.eval("self.length")[1])
+    length = int(widget.eval("self.length"))
     assert length == text_length
 
 
@@ -95,13 +95,13 @@ def test_current_layout_both_mode(manager_nospawn, minimal_conf_noscreen):
     config = get_widget_config(CurrentLayout(mode="both"), minimal_conf_noscreen)
     manager_nospawn.start(config)
     widget = manager_nospawn.c.widget["currentlayout"]
-    img_length = int(widget.eval("self.img_length")[1])
-    padding = int(widget.eval("self.padding")[1])
-    text_length = int(widget.eval("super(type(self), self).calculate_length()")[1])
+    img_length = int(widget.eval("self.img_length"))
+    padding = int(widget.eval("self.padding"))
+    text_length = int(widget.eval("super(type(self), self).calculate_length()"))
 
-    length = int(widget.eval("self.length")[1])
+    length = int(widget.eval("self.length"))
     assert length == text_length + img_length + padding
 
     widget.bar.fake_button_press(0, 0, button=3)
-    length = int(widget.eval("self.length")[1])
+    length = int(widget.eval("self.length"))
     assert length == text_length + img_length + padding
